Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(401)

Unified Diff: runtime/vm/compiler.cc

Issue 1584223006: Remove signature classes from the VM. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: sync Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/code_generator.cc ('k') | runtime/vm/dart_api_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/compiler.cc
diff --git a/runtime/vm/compiler.cc b/runtime/vm/compiler.cc
index 6775e2b3635f262f515f7c502c5fb52fc5ff804a..74795062b1ef56e71e69b289926e3e98ca2a5909 100644
--- a/runtime/vm/compiler.cc
+++ b/runtime/vm/compiler.cc
@@ -282,14 +282,13 @@ RawError* Compiler::CompileClass(const Class& cls) {
if (cls.is_marked_for_parsing()) {
return Error::null();
}
// If the class is a signature class there is no need to try and
// compile it. Just finalize it directly.
- if (cls.IsSignatureClass()) {
+ if (cls.IsTypedefClass()) {
#if defined(DEBUG)
- const Type& type = Type::Handle(
- Isolate::Current()->object_store()->function_impl_type());
- const Class& type_cls = Class::Handle(type.type_class());
- ASSERT(type_cls.is_finalized());
+ const Class& closure_cls = Class::Handle(
+ Isolate::Current()->object_store()->closure_class());
+ ASSERT(closure_cls.is_finalized());
#endif
LongJumpScope jump;
if (setjmp(*jump.Set()) == 0) {
@@ -282,14 +282,13 @@ RawError* Compiler::CompileClass(const Class& cls) {
return Error::null();
}
- // If the class is a signature class there is no need to try and
+ // If the class is a typedef class there is no need to try and
// compile it. Just finalize it directly.
« no previous file with comments | « runtime/vm/code_generator.cc ('k') | runtime/vm/dart_api_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698